@@ -166,7 +166,7 @@ class Em4DataStore:
         else:
             entity = elist[0]
             # delete("ClientInformation", email)
-            self.updateClient(id=entity.id, username=username, password=password, client_id=client_id)
+            self.updateUserAuthInformation(id=entity.id, username=username, password=password, client_id=client_id)
             logging.info('UserAuthInformation has been updated {}'.format(entity.id))
         message = str('upsert: UserAuthInformation has been inserted with ID :{}'.format(entity.id))
 
@@ -438,25 +438,25 @@ class Em4DataStore:
                 key = self.client.key("VehicleInformation", id)
                 task = self.client.get(key)
                 task["client_id"] = client_id
-                task["ftp_id"] = ftp_id,
-                task["tenant_id"] = tenant_id,
-                task["imei"] = imei,
-                task["department"] = department,
-                task["vin"] = vin,
-                task["license_plate"] = license_plate,
-                task["start_date"] = start_date,
-                task["make"] = make,
-                task["model"] = model,
-                task["year"] = year,
-                task["vehicle_id"] = vehicle_id,
-                task["odometer"] = odometer,
-                task["ecm_expiry_date"] = ecm_expiry_date,
-                task["activity_date"] = activity_date,
-                task["software"] = software,
-                task["latest_activity_date"] = latest_activity_date,
-                task["tested"] = tested,
-                task["comments"] = comments,
-                task["date_added"] = date_added,
+                task["ftp_id"] = ftp_id
+                task["tenant_id"] = tenant_id
+                task["imei"] = imei
+                task["department"] = department
+                task["vin"] = vin
+                task["license_plate"] = license_plate
+                task["start_date"] = start_date
+                task["make"] = make
+                task["model"] = model
+                task["year"] = year
+                task["vehicle_id"] = vehicle_id
+                task["odometer"] = odometer
+                task["ecm_expiry_date"] = ecm_expiry_date
+                task["activity_date"] = activity_date
+                task["software"] = software
+                task["latest_activity_date"] = latest_activity_date
+                task["tested"] = tested
+                task["comments"] = comments
+                task["date_added"] = date_added
                 task["user_id"] = user_id
                 self.client.put(task)
         # [END datastore_update]
@@ -888,124 +888,124 @@ class Em4DataStore:
             if id is not None:
                 key = self.client.key("EmCarsDailyRpt", id)
                 task = self.client.get(key)
-                task["res_sys_no_obd"] = res_sys_no_obd,
-                task["lic_st_id"] = lic_st_id,
-                task["ets_id"] = ets_id,
-                task["etnj2_sw_ver"] = etnj2_sw_ver,
-                task["vin"] = vin,
-                task["vin_src"] = vin_src,
-                task["vehicle_vin"] = vehicle_vin,
-                task["vehicle_vin_src"] = vehicle_vin_src,
-                task["obd2_vin_obd"] = obd2_vin_obd,
-                task["vin_mask"] = vin_mask,
-                task["lic_no_obd"] = lic_no_obd,
-                task["lic_jur_obd"] = lic_jur_obd,
-                task["lic_src"] = lic_src,
-                task["model_yr_obd"] = model_yr_obd,
-                task["make_obd"] = make_obd,
-                task["model_obd"] = model_obd,
-                task["gvwr"] = gvwr,
-                task["no_of_cyl"] = no_of_cyl,
-                task["eng_size"] = eng_size,
-                task["trans_type"] = trans_type,
-                task["fuel_cd"] = fuel_cd,
-                task["vid_sys_no"] = vid_sys_no,
-                task["curr_odo_rdng_obd"] = curr_odo_rdng_obd,
-                task["prev_odo_rdng_obd"] = prev_odo_rdng_obd,
-                task["mvc_reg_code"] = mvc_reg_code,
-                task["mvc_vehicle_type_code"] = mvc_vehicle_type_code,
-                task["test_type"] = test_type,
-                task["start_time_obd"] = start_time_obd,
-                task["end_time_obd"] = end_time_obd,
-                task["create_date_obd"] = create_date_obd,
-                task["prev_test_date"] = prev_test_date,
-                task["emiss_test_type"] = emiss_test_type,
-                task["primary_emiss_test_code"] = primary_emiss_test_code,
-                task["bulb_check_res"] = bulb_check_res,
-                task["chk_eng_light_on_obd"] = chk_eng_light_on_obd,
-                task["indicator_light_result"] = indicator_light_result,
-                task["exempt_from_obd"] = exempt_from_obd,
-                task["obd_bypassed"] = obd_bypassed,
-                task["bypass_obd_allowed"] = bypass_obd_allowed,
-                task["obd2_connect_res"] = obd2_connect_res,
-                task["communic_res"] = communic_res,
-                task["obd"] = obd,
-                task["obd2_test_fl"] = obd2_test_fl,
-                task["pcm_mudule_id"] = pcm_mudule_id,
-                task["obd_module_id_2"] = obd_module_id_2,
-                task["obd_module_id_3"] = obd_module_id_3,
-                task["obd_type"] = obd_type,
-                task["obd_calid"] = obd_calid,
-                task["obd_cvn"] = obd_cvn,
-                task["cvn_exclusion"] = cvn_exclusion,
-                task["pid_count_obd"] = pid_count_obd,
-                task["obd_pid00_obd"] = obd_pid00_obd,
-                task["obd_pid20_obd"] = obd_pid20_obd,
-                task["obd_pid40_obd"] = obd_pid40_obd,
-                task["obd_rpm_obd"] = obd_rpm_obd,
-                task["rpm_exclusion"] = rpm_exclusion,
-                task["misfire_mon_res_obd"] = misfire_mon_res_obd,
-                task["fuel_sys_mon_res_obd"] = fuel_sys_mon_res_obd,
-                task["comp_cmpnt_res_obd"] = comp_cmpnt_res_obd,
-                task["catalyst_mon_res_obd"] = catalyst_mon_res_obd,
-                task["heat_cat_mon_res_obd"] = heat_cat_mon_res_obd,
-                task["evap_sys_mon_res_obd"] = evap_sys_mon_res_obd,
-                task["sec_air_sys_mon_res_obd"] = sec_air_sys_mon_res_obd,
-                task["air_cond_mon_res_obd"] = air_cond_mon_res_obd,
-                task["oxy_sens_mon_res_obd"] = oxy_sens_mon_res_obd,
-                task["htd_oxy_sns_mon_res_obd"] = htd_oxy_sns_mon_res_obd,
-                task["egr_sys_mon_res_obd"] = egr_sys_mon_res_obd,
-                task["rdy_mon_obd"] = rdy_mon_obd,
-                task["tot_unset_rdy_mon"] = tot_unset_rdy_mon,
-                task["readiness_status"] = readiness_status,
-                task["continuous_monit_xclusion"] = continuous_monit_xclusion,
-                task["exempt_from_readiness"] = exempt_from_readiness,
-                task["mil_command_stat"] = mil_command_stat,
-                task["dtc1_obd"] = dtc1_obd,
-                task["dtc2_obd"] = dtc2_obd,
-                task["dtc3_obd"] = dtc3_obd,
-                task["dtc4_obd"] = dtc4_obd,
-                task["dtc5_obd"] = dtc5_obd,
-                task["dtc6_obd"] = dtc6_obd,
-                task["dtc7_obd"] = dtc7_obd,
-                task["dtc8_obd"] = dtc8_obd,
-                task["dtc9_obd"] = dtc9_obd,
-                task["dtc10_obd"] = dtc10_obd,
-                task["tot_stored_dtcs_obd"] = tot_stored_dtcs_obd,
-                task["catalyst_dtc_pres_obd"] = catalyst_dtc_pres_obd,
-                task["pend_dtc1_obd"] = pend_dtc1_obd,
-                task["pend_dtc2_obd"] = pend_dtc2_obd,
-                task["pend_dtc3_obd"] = pend_dtc3_obd,
-                task["pend_dtc4_obd"] = pend_dtc4_obd,
-                task["pend_dtc5_obd"] = pend_dtc5_obd,
-                task["pend_dtc6_obd"] = pend_dtc6_obd,
-                task["pend_dtc7_obd"] = pend_dtc7_obd,
-                task["pend_dtc8_obd"] = pend_dtc8_obd,
-                task["pend_dtc9_obd"] = pend_dtc9_obd,
-                task["pend_dtc10_obd"] = pend_dtc10_obd,
-                task["cat_retest_exclusion"] = cat_retest_exclusion,
-                task["obd_warmups_obd"] = obd_warmups_obd,
-                task["obd_code_cleared_distance_obd"] = obd_code_cleared_distance_obd,
-                task["obd_mil_on_distance_obd"] = obd_mil_on_distance_obd,
-                task["obd_code_cleared_time_obd"] = obd_code_cleared_time_obd,
-                task["obd_mil_on_time_obd"] = obd_mil_on_time_obd,
-                task["emiss_clarification"] = emiss_clarification,
-                task["misc_comnt"] = misc_comnt,
-                task["misc_comnt_res"] = misc_comnt_res,
-                task["misc_emiss_reject_comment"] = misc_emiss_reject_comment,
-                task["misc_emiss_reject_result"] = misc_emiss_reject_result,
-                task["overall_tamper_result"] = overall_tamper_result,
-                task["ex_sys_res"] = ex_sys_res,
-                task["overall_obd2_res"] = overall_obd2_res,
-                task["exh_emiss_test_res"] = exh_emiss_test_res,
-                task["overall_gas_cap_res"] = overall_gas_cap_res,
-                task["ovr_exh_obd2_em_res"] = ovr_exh_obd2_em_res,
-                task["overall_emiss_res"] = overall_emiss_res,
-                task["overall_saf_res"] = overall_saf_res,
-                task["overall_test_res"] = overall_test_res,
-                task["created_date_sys"] = created_date_sys,
-                task["created_user_sys"] = created_user_sys,
-                task["update_date_sys"] = update_date_sys,
+                task["res_sys_no_obd"] = res_sys_no_obd
+                task["lic_st_id"] = lic_st_id
+                task["ets_id"] = ets_id
+                task["etnj2_sw_ver"] = etnj2_sw_ver
+                task["vin"] = vin
+                task["vin_src"] = vin_src
+                task["vehicle_vin"] = vehicle_vin
+                task["vehicle_vin_src"] = vehicle_vin_src
+                task["obd2_vin_obd"] = obd2_vin_obd
+                task["vin_mask"] = vin_mask
+                task["lic_no_obd"] = lic_no_obd
+                task["lic_jur_obd"] = lic_jur_obd
+                task["lic_src"] = lic_src
+                task["model_yr_obd"] = model_yr_obd
+                task["make_obd"] = make_obd
+                task["model_obd"] = model_obd
+                task["gvwr"] = gvwr
+                task["no_of_cyl"] = no_of_cyl
+                task["eng_size"] = eng_size
+                task["trans_type"] = trans_type
+                task["fuel_cd"] = fuel_cd
+                task["vid_sys_no"] = vid_sys_no
+                task["curr_odo_rdng_obd"] = curr_odo_rdng_obd
+                task["prev_odo_rdng_obd"] = prev_odo_rdng_obd
+                task["mvc_reg_code"] = mvc_reg_code
+                task["mvc_vehicle_type_code"] = mvc_vehicle_type_code
+                task["test_type"] = test_type
+                task["start_time_obd"] = start_time_obd
+                task["end_time_obd"] = end_time_obd
+                task["create_date_obd"] = create_date_obd
+                task["prev_test_date"] = prev_test_date
+                task["emiss_test_type"] = emiss_test_type
+                task["primary_emiss_test_code"] = primary_emiss_test_code
+                task["bulb_check_res"] = bulb_check_res
+                task["chk_eng_light_on_obd"] = chk_eng_light_on_obd
+                task["indicator_light_result"] = indicator_light_result
+                task["exempt_from_obd"] = exempt_from_obd
+                task["obd_bypassed"] = obd_bypassed
+                task["bypass_obd_allowed"] = bypass_obd_allowed
+                task["obd2_connect_res"] = obd2_connect_res
+                task["communic_res"] = communic_res
+                task["obd"] = obd
+                task["obd2_test_fl"] = obd2_test_fl
+                task["pcm_mudule_id"] = pcm_mudule_id
+                task["obd_module_id_2"] = obd_module_id_2
+                task["obd_module_id_3"] = obd_module_id_3
+                task["obd_type"] = obd_type
+                task["obd_calid"] = obd_calid
+                task["obd_cvn"] = obd_cvn
+                task["cvn_exclusion"] = cvn_exclusion
+                task["pid_count_obd"] = pid_count_obd
+                task["obd_pid00_obd"] = obd_pid00_obd
+                task["obd_pid20_obd"] = obd_pid20_obd
+                task["obd_pid40_obd"] = obd_pid40_obd
+                task["obd_rpm_obd"] = obd_rpm_obd
+                task["rpm_exclusion"] = rpm_exclusion
+                task["misfire_mon_res_obd"] = misfire_mon_res_obd
+                task["fuel_sys_mon_res_obd"] = fuel_sys_mon_res_obd
+                task["comp_cmpnt_res_obd"] = comp_cmpnt_res_obd
+                task["catalyst_mon_res_obd"] = catalyst_mon_res_obd
+                task["heat_cat_mon_res_obd"] = heat_cat_mon_res_obd
+                task["evap_sys_mon_res_obd"] = evap_sys_mon_res_obd
+                task["sec_air_sys_mon_res_obd"] = sec_air_sys_mon_res_obd
+                task["air_cond_mon_res_obd"] = air_cond_mon_res_obd
+                task["oxy_sens_mon_res_obd"] = oxy_sens_mon_res_obd
+                task["htd_oxy_sns_mon_res_obd"] = htd_oxy_sns_mon_res_obd
+                task["egr_sys_mon_res_obd"] = egr_sys_mon_res_obd
+                task["rdy_mon_obd"] = rdy_mon_obd
+                task["tot_unset_rdy_mon"] = tot_unset_rdy_mon
+                task["readiness_status"] = readiness_status
+                task["continuous_monit_xclusion"] = continuous_monit_xclusion
+                task["exempt_from_readiness"] = exempt_from_readiness
+                task["mil_command_stat"] = mil_command_stat
+                task["dtc1_obd"] = dtc1_obd
+                task["dtc2_obd"] = dtc2_obd
+                task["dtc3_obd"] = dtc3_obd
+                task["dtc4_obd"] = dtc4_obd
+                task["dtc5_obd"] = dtc5_obd
+                task["dtc6_obd"] = dtc6_obd
+                task["dtc7_obd"] = dtc7_obd
+                task["dtc8_obd"] = dtc8_obd
+                task["dtc9_obd"] = dtc9_obd
+                task["dtc10_obd"] = dtc10_obd
+                task["tot_stored_dtcs_obd"] = tot_stored_dtcs_obd
+                task["catalyst_dtc_pres_obd"] = catalyst_dtc_pres_obd
+                task["pend_dtc1_obd"] = pend_dtc1_obd
+                task["pend_dtc2_obd"] = pend_dtc2_obd
+                task["pend_dtc3_obd"] = pend_dtc3_obd
+                task["pend_dtc4_obd"] = pend_dtc4_obd
+                task["pend_dtc5_obd"] = pend_dtc5_obd
+                task["pend_dtc6_obd"] = pend_dtc6_obd
+                task["pend_dtc7_obd"] = pend_dtc7_obd
+                task["pend_dtc8_obd"] = pend_dtc8_obd
+                task["pend_dtc9_obd"] = pend_dtc9_obd
+                task["pend_dtc10_obd"] = pend_dtc10_obd
+                task["cat_retest_exclusion"] = cat_retest_exclusion
+                task["obd_warmups_obd"] = obd_warmups_obd
+                task["obd_code_cleared_distance_obd"] = obd_code_cleared_distance_obd
+                task["obd_mil_on_distance_obd"] = obd_mil_on_distance_obd
+                task["obd_code_cleared_time_obd"] = obd_code_cleared_time_obd
+                task["obd_mil_on_time_obd"] = obd_mil_on_time_obd
+                task["emiss_clarification"] = emiss_clarification
+                task["misc_comnt"] = misc_comnt
+                task["misc_comnt_res"] = misc_comnt_res
+                task["misc_emiss_reject_comment"] = misc_emiss_reject_comment
+                task["misc_emiss_reject_result"] = misc_emiss_reject_result
+                task["overall_tamper_result"] = overall_tamper_result
+                task["ex_sys_res"] = ex_sys_res
+                task["overall_obd2_res"] = overall_obd2_res
+                task["exh_emiss_test_res"] = exh_emiss_test_res
+                task["overall_gas_cap_res"] = overall_gas_cap_res
+                task["ovr_exh_obd2_em_res"] = ovr_exh_obd2_em_res
+                task["overall_emiss_res"] = overall_emiss_res
+                task["overall_saf_res"] = overall_saf_res
+                task["overall_test_res"] = overall_test_res
+                task["created_date_sys"] = created_date_sys
+                task["created_user_sys"] = created_user_sys
+                task["update_date_sys"] = update_date_sys
                 task["update_user_sys"] = update_user_sys
                 self.client.put(task)
         # [END datastore_update]
